@@ -35,7 +35,7 @@
 #include "mm-base-bearer.h"
 #include "mm-base-modem-at.h"
 #include "mm-base-modem.h"
-#include "mm-log.h"
+#include "mm-log-object.h"
 #include "mm-modem-helpers.h"
 #include "mm-bearer-stats.h"
 
@@ -50,7 +50,10 @@
 #define BEARER_CONNECTION_MONITOR_INITIAL_TIMEOUT 30
 #define BEARER_CONNECTION_MONITOR_TIMEOUT          5
 
-G_DEFINE_TYPE (MMBaseBearer, mm_base_bearer, MM_GDBUS_TYPE_BEARER_SKELETON)
+static void log_object_iface_init (MMLogObjectInterface *iface);
+
+G_DEFINE_TYPE_EXTENDED (MMBaseBearer, mm_base_bearer, MM_GDBUS_TYPE_BEARER_SKELETON, 0,
+                        G_IMPLEMENT_INTERFACE (MM_TYPE_LOG_OBJECT, log_object_iface_init))
 
 typedef enum {
     CONNECTION_FORBIDDEN_REASON_NONE,
@@ -76,6 +79,8 @@ static GParamSpec *properties[PROP_LAST];
 struct _MMBaseBearerPrivate {
     /* The connection to the system bus */
     GDBusConnection *connection;
+    guint            dbus_id;
+
     /* The modem which owns this BEARER */
     MMBaseModem *modem;
     /* The path where the BEARER object is exported */
@@ -139,10 +144,9 @@ static const gchar *connection_forbidden_reason_str [CONNECTION_FORBIDDEN_REASON
 void
 mm_base_bearer_export (MMBaseBearer *self)
 {
-    static guint id = 0;
     gchar *path;
 
-    path = g_strdup_printf (MM_DBUS_BEARER_PREFIX "/%d", id++);
+    path = g_strdup_printf (MM_DBUS_BEARER_PREFIX "/%d", self->priv->dbus_id);
     g_object_set (self,
                   MM_BASE_BEARER_PATH, path,
                   NULL);
@@ -171,14 +175,14 @@ load_connection_status_ready (MMBaseBearer *self,
     if (status == MM_BEARER_CONNECTION_STATUS_UNKNOWN) {
         /* Only warn if not reporting an "unsupported" error */
         if (!g_error_matches (error, MM_CORE_ERROR, MM_CORE_ERROR_UNSUPPORTED)) {
-            mm_warn ("checking if connected failed: %s", error->message);
+            mm_obj_warn (self, "checking if connected failed: %s", error->message);
             g_error_free (error);
             return;
         }
 
         /* If we're being told that connection monitoring is unsupported, just
          * ignore the error and remove the timeout. */
-        mm_dbg ("Connection monitoring is unsupported by the device");
+        mm_obj_dbg (self, "connection monitoring is unsupported by the device");
         self->priv->load_connection_status_unsupported = TRUE;
         connection_monitor_stop (self);
         g_error_free (error);
@@ -187,7 +191,7 @@ load_connection_status_ready (MMBaseBearer *self,
 
     /* Report connection or disconnection */
     g_assert (status == MM_BEARER_CONNECTION_STATUS_CONNECTED || status == MM_BEARER_CONNECTION_STATUS_DISCONNECTED);
-    mm_dbg ("connection status loaded: %s", mm_bearer_connection_status_get_string (status));
+    mm_obj_dbg (self, "connection status loaded: %s", mm_bearer_connection_status_get_string (status));
     mm_base_bearer_report_connection_status (self, status);
 }
 
@@ -250,18 +254,73 @@ bearer_update_interface_stats (MMBaseBearer *self)
 }
 
 static void
-bearer_reset_interface_stats (MMBaseBearer *self)
+bearer_reset_ongoing_interface_stats (MMBaseBearer *self)
 {
-    g_clear_object (&self->priv->stats);
-    mm_gdbus_bearer_set_stats (MM_GDBUS_BEARER (self), NULL);
+    mm_bearer_stats_set_duration (self->priv->stats, 0);
+    mm_bearer_stats_set_tx_bytes (self->priv->stats, 0);
+    mm_bearer_stats_set_rx_bytes (self->priv->stats, 0);
+    bearer_update_interface_stats (self);
+}
+
+static void
+bearer_set_ongoing_interface_stats (MMBaseBearer *self,
+                                    guint         duration,
+                                    guint64       rx_bytes,
+                                    guint64       tx_bytes)
+{
+    guint n_updates = 0;
+
+    /* Make sure we don't reset to 0 these values if we had ever set them
+     * before. Just ignore the update if we're reported 0 */
+
+    if (duration) {
+        gint delta_duration;
+
+        delta_duration = duration - mm_bearer_stats_get_duration (self->priv->stats);
+        if (delta_duration > 0) {
+            mm_bearer_stats_set_duration (self->priv->stats, duration);
+            mm_bearer_stats_set_total_duration (self->priv->stats,
+                                                mm_bearer_stats_get_total_duration (self->priv->stats) + delta_duration);
+            n_updates++;
+        }
+    }
+
+    if (rx_bytes) {
+        gint64 delta_rx_bytes;
+
+        delta_rx_bytes = rx_bytes - mm_bearer_stats_get_rx_bytes (self->priv->stats);
+        if (delta_rx_bytes > 0) {
+            mm_bearer_stats_set_rx_bytes (self->priv->stats, rx_bytes);
+            mm_bearer_stats_set_total_rx_bytes (self->priv->stats,
+                                                mm_bearer_stats_get_total_rx_bytes (self->priv->stats) + delta_rx_bytes);
+            n_updates++;
+        }
+    }
+
+    if (tx_bytes) {
+        gint64 delta_tx_bytes;
+
+        delta_tx_bytes = tx_bytes - mm_bearer_stats_get_tx_bytes (self->priv->stats);
+        if (delta_tx_bytes > 0) {
+            mm_bearer_stats_set_tx_bytes (self->priv->stats, tx_bytes);
+            mm_bearer_stats_set_total_tx_bytes (self->priv->stats,
+                                                mm_bearer_stats_get_total_tx_bytes (self->priv->stats) + delta_tx_bytes);
+            n_updates++;
+        }
+    }
+
+    if (n_updates)
+        bearer_update_interface_stats (self);
 }
 
 static void
 bearer_stats_stop (MMBaseBearer *self)
 {
     if (self->priv->duration_timer) {
-        if (self->priv->stats)
-            mm_bearer_stats_set_duration (self->priv->stats, (guint64) g_timer_elapsed (self->priv->duration_timer, NULL));
+        bearer_set_ongoing_interface_stats (self,
+                                            (guint64) g_timer_elapsed (self->priv->duration_timer, NULL),
+                                            0,
+                                            0);
         g_timer_destroy (self->priv->duration_timer);
         self->priv->duration_timer = NULL;
     }
@@ -283,14 +342,14 @@ reload_stats_ready (MMBaseBearer *self,
     if (!MM_BASE_BEARER_GET_CLASS (self)->reload_stats_finish (self, &rx_bytes, &tx_bytes, res, &error)) {
         /* If reloading stats fails, warn about it and don't update anything */
         if (!g_error_matches (error, MM_CORE_ERROR, MM_CORE_ERROR_UNSUPPORTED)) {
-            mm_warn ("Reloading stats failed: %s", error->message);
+            mm_obj_warn (self, "reloading stats failed: %s", error->message);
             g_error_free (error);
             return;
         }
 
         /* If we're being told that reloading stats is unsupported, just ignore
          * the error and update oly the duration timer. */
-        mm_dbg ("Reloading stats is unsupported by the device");
+        mm_obj_dbg (self, "reloading stats is unsupported by the device");
         self->priv->reload_stats_unsupported = TRUE;
         rx_bytes = 0;
         tx_bytes = 0;
@@ -298,10 +357,10 @@ reload_stats_ready (MMBaseBearer *self,
     }
 
     /* We only update stats if they were retrieved properly */
-    mm_bearer_stats_set_duration (self->priv->stats, (guint32) g_timer_elapsed (self->priv->duration_timer, NULL));
-    mm_bearer_stats_set_tx_bytes (self->priv->stats, tx_bytes);
-    mm_bearer_stats_set_rx_bytes (self->priv->stats, rx_bytes);
-    bearer_update_interface_stats (self);
+    bearer_set_ongoing_interface_stats (self,
+                                        (guint32) g_timer_elapsed (self->priv->duration_timer, NULL),
+                                        rx_bytes,
+                                        tx_bytes);
 }
 
 static gboolean
@@ -323,21 +382,16 @@ stats_update_cb (MMBaseBearer *self)
     }
 
     /* Otherwise, just update duration and we're done */
-    mm_bearer_stats_set_duration (self->priv->stats, (guint32) g_timer_elapsed (self->priv->duration_timer, NULL));
-    mm_bearer_stats_set_tx_bytes (self->priv->stats, 0);
-    mm_bearer_stats_set_rx_bytes (self->priv->stats, 0);
-    bearer_update_interface_stats (self);
+    bearer_set_ongoing_interface_stats (self,
+                                        (guint32) g_timer_elapsed (self->priv->duration_timer, NULL),
+                                        0,
+                                        0);
     return G_SOURCE_CONTINUE;
 }
 
 static void
 bearer_stats_start (MMBaseBearer *self)
 {
-    /* Allocate new stats object. If there was one already created from a
-     * previous run, deallocate it */
-    g_assert (!self->priv->stats);
-    self->priv->stats = mm_bearer_stats_new ();
-
     /* Start duration timer */
     g_assert (!self->priv->duration_timer);
     self->priv->duration_timer = g_timer_new ();
@@ -374,6 +428,10 @@ bearer_update_status (MMBaseBearer *self,
     /* NOTE: we do allow status 'CONNECTED' here; it may happen if we go into
      * DISCONNECTING and we cannot disconnect */
 
+    /* Do nothing if the status is the same */
+    if (self->priv->status == status)
+        return;
+
     /* Update the property value */
     self->priv->status = status;
     g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_STATUS]);
@@ -381,6 +439,8 @@ bearer_update_status (MMBaseBearer *self,
     /* Ensure that we don't expose any connection related data in the
      * interface when going into disconnected state. */
     if (self->priv->status == MM_BEARER_STATUS_DISCONNECTED) {
+        g_autoptr(GString) report = NULL;
+
         bearer_reset_interface_status (self);
         /* Cleanup flag to ignore disconnection reports */
         self->priv->ignore_disconnection_reports = FALSE;
@@ -388,6 +448,19 @@ bearer_update_status (MMBaseBearer *self,
         bearer_stats_stop (self);
         /* Stop connection monitoring */
         connection_monitor_stop (self);
+
+        /* Build and log report */
+        report = g_string_new (NULL);
+        g_string_append_printf (report,
+                                "connection #%u finished: duration %us",
+                                mm_bearer_stats_get_attempts (self->priv->stats),
+                                mm_bearer_stats_get_duration (self->priv->stats));
+        if (!self->priv->reload_stats_unsupported)
+            g_string_append_printf (report,
+                                    ", tx: %" G_GUINT64_FORMAT " bytes, rx :%" G_GUINT64_FORMAT " bytes",
+                                    mm_bearer_stats_get_tx_bytes (self->priv->stats),
+                                    mm_bearer_stats_get_rx_bytes (self->priv->stats));
+        mm_obj_info (self, "%s", report->str);
     }
 }
 
@@ -413,7 +486,7 @@ bearer_update_status_connected (MMBaseBearer *self,
      * the bearer when ownership of the TTY is given back to MM. */
     if ((ipv4_config && mm_bearer_ip_config_get_method (ipv4_config) == MM_BEARER_IP_METHOD_PPP) ||
         (ipv6_config && mm_bearer_ip_config_get_method (ipv6_config) == MM_BEARER_IP_METHOD_PPP)) {
-        mm_dbg ("PPP is required for connection, will ignore disconnection reports");
+        mm_obj_dbg (self, "PPP is required for connection, will ignore disconnection reports");
         self->priv->ignore_disconnection_reports = TRUE;
     }
 
@@ -450,7 +523,7 @@ deferred_3gpp_unregistration_cb (MMBaseBearer *self)
     g_warn_if_fail (self->priv->reason_3gpp == CONNECTION_FORBIDDEN_REASON_UNREGISTERED);
     self->priv->deferred_3gpp_unregistration_id = 0;
 
-    mm_dbg ("Forcing bearer disconnection, not registered in 3GPP network");
+    mm_obj_dbg (self, "forcing bearer disconnection, not registered in 3GPP network");
     mm_base_bearer_disconnect_force (self);
     return G_SOURCE_REMOVE;
 }
@@ -476,6 +549,7 @@ modem_3gpp_registration_state_changed (MMIfaceModem3gpp *modem,
     case MM_MODEM_3GPP_REGISTRATION_STATE_HOME_SMS_ONLY:
     case MM_MODEM_3GPP_REGISTRATION_STATE_HOME_CSFB_NOT_PREFERRED:
     case MM_MODEM_3GPP_REGISTRATION_STATE_SEARCHING:
+    case MM_MODEM_3GPP_REGISTRATION_STATE_ATTACHED_RLOS:
         self->priv->reason_3gpp = CONNECTION_FORBIDDEN_REASON_NONE;
         break;
     case MM_MODEM_3GPP_REGISTRATION_STATE_ROAMING:
@@ -489,6 +563,8 @@ modem_3gpp_registration_state_changed (MMIfaceModem3gpp *modem,
     case MM_MODEM_3GPP_REGISTRATION_STATE_EMERGENCY_ONLY:
         self->priv->reason_3gpp = CONNECTION_FORBIDDEN_REASON_EMERGENCY_ONLY;
         break;
+    default:
+        g_assert_not_reached ();
     }
 
     /* If no reason to disconnect, or if it's a mixed CDMA+LTE modem without a CDMA reason,
@@ -502,7 +578,7 @@ modem_3gpp_registration_state_changed (MMIfaceModem3gpp *modem,
 
     /* Modem is roaming and roaming not allowed, report right away */
     if (self->priv->reason_3gpp == CONNECTION_FORBIDDEN_REASON_ROAMING) {
-        mm_dbg ("Bearer not allowed to connect, registered in roaming 3GPP network");
+        mm_obj_dbg (self, "bearer not allowed to connect, registered in roaming 3GPP network");
         reset_deferred_unregistration (self);
         mm_base_bearer_disconnect_force (self);
         return;
@@ -510,7 +586,7 @@ modem_3gpp_registration_state_changed (MMIfaceModem3gpp *modem,
 
     /* Modem is registered under emergency services only? */
     if (self->priv->reason_3gpp == CONNECTION_FORBIDDEN_REASON_EMERGENCY_ONLY) {
-        mm_dbg ("Bearer not allowed to connect, emergency services only");
+        mm_obj_dbg (self, "bearer not allowed to connect, emergency services only");
         reset_deferred_unregistration (self);
         mm_base_bearer_disconnect_force (self);
         return;
@@ -524,13 +600,13 @@ modem_3gpp_registration_state_changed (MMIfaceModem3gpp *modem,
 
         /* If the bearer is not connected, report right away */
         if (self->priv->status != MM_BEARER_STATUS_CONNECTED) {
-            mm_dbg ("Bearer not allowed to connect, not registered in 3GPP network");
+            mm_obj_dbg (self, "bearer not allowed to connect, not registered in 3GPP network");
             mm_base_bearer_disconnect_force (self);
             return;
         }
 
         /* Otherwise, setup the new timeout */
-        mm_dbg ("Connected bearer not registered in 3GPP network");
+        mm_obj_dbg (self, "connected bearer not registered in 3GPP network");
         self->priv->deferred_3gpp_unregistration_id =
             g_timeout_add_seconds (BEARER_DEFERRED_UNREGISTRATION_TIMEOUT,
                                    (GSourceFunc) deferred_3gpp_unregistration_cb,
@@ -547,7 +623,7 @@ deferred_cdma_unregistration_cb (MMBaseBearer *self)
     g_warn_if_fail (self->priv->reason_cdma == CONNECTION_FORBIDDEN_REASON_UNREGISTERED);
     self->priv->deferred_cdma_unregistration_id = 0;
 
-    mm_dbg ("Forcing bearer disconnection, not registered in CDMA network");
+    mm_obj_dbg (self, "forcing bearer disconnection, not registered in CDMA network");
     mm_base_bearer_disconnect_force (self);
     return G_SOURCE_REMOVE;
 }
@@ -589,7 +665,7 @@ modem_cdma_registration_state_changed (MMIfaceModemCdma *modem,
 
     /* Modem is roaming and roaming not allowed, report right away */
     if (self->priv->reason_cdma == CONNECTION_FORBIDDEN_REASON_ROAMING) {
-        mm_dbg ("Bearer not allowed to connect, registered in roaming CDMA network");
+        mm_obj_dbg (self, "bearer not allowed to connect, registered in roaming CDMA network");
         reset_deferred_unregistration (self);
         mm_base_bearer_disconnect_force (self);
         return;
@@ -603,13 +679,13 @@ modem_cdma_registration_state_changed (MMIfaceModemCdma *modem,
 
         /* If the bearer is not connected, report right away */
         if (self->priv->status != MM_BEARER_STATUS_CONNECTED) {
-            mm_dbg ("Bearer not allowed to connect, not registered in CDMA network");
+            mm_obj_dbg (self, "bearer not allowed to connect, not registered in CDMA network");
             mm_base_bearer_disconnect_force (self);
             return;
         }
 
         /* Otherwise, setup the new timeout */
-        mm_dbg ("Connected bearer not registered in CDMA network");
+        mm_obj_dbg (self, "connected bearer not registered in CDMA network");
         self->priv->deferred_cdma_unregistration_id =
             g_timeout_add_seconds (BEARER_DEFERRED_UNREGISTRATION_TIMEOUT,
                                    (GSourceFunc) deferred_cdma_unregistration_cb,
@@ -698,14 +774,11 @@ disconnect_after_cancel_ready (MMBaseBearer *self,
     GError *error = NULL;
 
     if (!MM_BASE_BEARER_GET_CLASS (self)->disconnect_finish (self, res, &error)) {
-        mm_warn ("Error disconnecting bearer '%s': '%s'. "
-                 "Will assume disconnected anyway.",
-                 self->priv->path,
-                 error->message);
+        mm_obj_warn (self, "error disconnecting: %s; will assume disconnected anyway", error->message);
         g_error_free (error);
     }
     else
-        mm_dbg ("Disconnected bearer '%s'", self->priv->path);
+        mm_obj_dbg (self, "disconnected bearer '%s'", self->priv->path);
 
     /* Report disconnection to the bearer object using class method
      * mm_bearer_report_connection_status. This gives subclass implementations a
@@ -727,9 +800,15 @@ connect_ready (MMBaseBearer *self,
     /* NOTE: connect() implementations *MUST* handle cancellations themselves */
     result = MM_BASE_BEARER_GET_CLASS (self)->connect_finish (self, res, &error);
     if (!result) {
-        mm_dbg ("Couldn't connect bearer '%s': '%s'",
-                self->priv->path,
-                error->message);
+        mm_obj_warn (self, "connection attempt #%u failed: %s",
+                     mm_bearer_stats_get_attempts (self->priv->stats),
+                     error->message);
+
+        /* Update failed attempts */
+        mm_bearer_stats_set_failed_attempts (self->priv->stats,
+                                             mm_bearer_stats_get_failed_attempts (self->priv->stats) + 1);
+        bearer_update_interface_stats (self);
+
         if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
             /* Will launch disconnection */
             launch_disconnect = TRUE;
@@ -738,14 +817,14 @@ connect_ready (MMBaseBearer *self,
     }
     /* Handle cancellations detected after successful connection */
     else if (g_cancellable_is_cancelled (self->priv->connect_cancellable)) {
-        mm_dbg ("Connected bearer '%s', but need to disconnect", self->priv->path);
+        mm_obj_dbg (self, "connected, but need to disconnect");
         mm_bearer_connect_result_unref (result);
         error = g_error_new (G_IO_ERROR, G_IO_ERROR_CANCELLED,
                              "Bearer got connected, but had to disconnect after cancellation request");
         launch_disconnect = TRUE;
     }
     else {
-        mm_dbg ("Connected bearer '%s'", self->priv->path);
+        mm_obj_dbg (self, "connected");
 
         /* Update bearer and interface status */
         bearer_update_status_connected (
@@ -860,11 +939,15 @@ mm_base_bearer_connect (MMBaseBearer *self,
         return;
     }
 
+    /* Update total attempts */
+    mm_bearer_stats_set_attempts (self->priv->stats,
+                                  mm_bearer_stats_get_attempts (self->priv->stats) + 1);
+    bearer_reset_ongoing_interface_stats (self);
+
     /* Connecting! */
-    mm_dbg ("Connecting bearer '%s'", self->priv->path);
+    mm_obj_dbg (self, "connecting...");
     self->priv->connect_cancellable = g_cancellable_new ();
     bearer_update_status (self, MM_BEARER_STATUS_CONNECTING);
-    bearer_reset_interface_stats (self);
     MM_BASE_BEARER_GET_CLASS (self)->connect (
         self,
         self->priv->connect_cancellable,
@@ -933,7 +1016,7 @@ handle_connect (MMBaseBearer *self,
                   MM_BASE_BEARER_MODEM, &ctx->modem,
                   NULL);
 
-    mm_dbg ("User request to connect bearer '%s'", self->priv->path);
+    mm_obj_dbg (self, "user request to connect");
 
     mm_base_modem_authorize (ctx->modem,
                              invocation,
@@ -962,12 +1045,12 @@ disconnect_ready (MMBaseBearer *self,
     GError *error = NULL;
 
     if (!MM_BASE_BEARER_GET_CLASS (self)->disconnect_finish (self, res, &error)) {
-        mm_dbg ("Couldn't disconnect bearer '%s': %s", self->priv->path, error->message);
+        mm_obj_dbg (self, "couldn't disconnect: %s", error->message);
         bearer_update_status (self, MM_BEARER_STATUS_CONNECTED);
         g_task_return_error (task, error);
     }
     else {
-        mm_dbg ("Disconnected bearer '%s'", self->priv->path);
+        mm_obj_dbg (self, "disconnected");
         bearer_update_status (self, MM_BEARER_STATUS_DISCONNECTED);
         g_task_return_boolean (task, TRUE);
     }
@@ -985,8 +1068,7 @@ status_changed_complete_disconnect (MMBaseBearer *self,
     if (self->priv->status != MM_BEARER_STATUS_DISCONNECTED)
         return;
 
-    mm_dbg ("Disconnected bearer '%s' after cancelling previous connect request",
-            self->priv->path);
+    mm_obj_dbg (self, "disconnected after cancelling previous connect request");
     g_signal_handler_disconnect (self,
                                  self->priv->disconnect_signal_handler);
     self->priv->disconnect_signal_handler = 0;
@@ -1035,7 +1117,7 @@ mm_base_bearer_disconnect (MMBaseBearer *self,
         return;
     }
 
-    mm_dbg ("Disconnecting bearer '%s'", self->priv->path);
+    mm_obj_dbg (self, "disconnecting...");
 
     /* If currently connecting, try to cancel that operation, and wait to get
      * disconnected. */
@@ -1126,7 +1208,7 @@ handle_disconnect (MMBaseBearer *self,
                   MM_BASE_BEARER_MODEM, &ctx->modem,
                   NULL);
 
-    mm_dbg ("User request to disconnect bearer '%s'", self->priv->path);
+    mm_obj_dbg (self, "user request to disconnect");
 
     mm_base_modem_authorize (ctx->modem,
                              invocation,
@@ -1157,9 +1239,7 @@ base_bearer_dbus_export (MMBaseBearer *self)
                                            self->priv->connection,
                                            self->priv->path,
                                            &error)) {
-        mm_warn ("couldn't export BEARER at '%s': '%s'",
-                 self->priv->path,
-                 error->message);
+        mm_obj_warn (self, "couldn't export to bus: %s", error->message);
         g_error_free (error);
     }
 }
@@ -1172,7 +1252,7 @@ base_bearer_dbus_unexport (MMBaseBearer *self)
     path = g_dbus_interface_skeleton_get_object_path (G_DBUS_INTERFACE_SKELETON (self));
     /* Only unexport if currently exported */
     if (path) {
-        mm_dbg ("Removing from DBus bearer at '%s'", path);
+        mm_obj_dbg (self, "removing from bus");
         g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (self));
     }
 }
@@ -1220,14 +1300,11 @@ disconnect_force_ready (MMBaseBearer *self,
     GError *error = NULL;
 
     if (!MM_BASE_BEARER_GET_CLASS (self)->disconnect_finish (self, res, &error)) {
-        mm_warn ("Error disconnecting bearer '%s': '%s'. "
-                 "Will assume disconnected anyway.",
-                 self->priv->path,
-                 error->message);
+        mm_obj_warn (self, "error disconnecting: %s; will assume disconnected anyway", error->message);
         g_error_free (error);
     }
     else
-        mm_dbg ("Disconnected bearer '%s'", self->priv->path);
+        mm_obj_dbg (self, "disconnected");
 
     /* Report disconnection to the bearer object using class method
      * mm_bearer_report_connection_status. This gives subclass implementations a
@@ -1244,7 +1321,7 @@ mm_base_bearer_disconnect_force (MMBaseBearer *self)
         self->priv->status == MM_BEARER_STATUS_DISCONNECTED)
         return;
 
-    mm_dbg ("Forcing disconnection of bearer '%s'", self->priv->path);
+    mm_obj_dbg (self, "forcing disconnection");
 
     /* If currently connecting, try to cancel that operation. */
     if (self->priv->status == MM_BEARER_STATUS_CONNECTING) {
@@ -1308,7 +1385,7 @@ mm_base_bearer_report_connection_status (MMBaseBearer             *self,
                                          MMBearerConnectionStatus  status)
 {
     if ((status == MM_BEARER_CONNECTION_STATUS_DISCONNECTED) && self->priv->ignore_disconnection_reports) {
-        mm_dbg ("ignoring disconnection report for bearer '%s'", self->priv->path);
+        mm_obj_dbg (self, "ignoring disconnection report");
         return;
     }
 
@@ -1317,6 +1394,17 @@ mm_base_bearer_report_connection_status (MMBaseBearer             *self,
 
 /*****************************************************************************/
 
+static gchar *
+log_object_build_id (MMLogObject *_self)
+{
+    MMBaseBearer *self;
+
+    self = MM_BASE_BEARER (_self);
+    return g_strdup_printf ("bearer%u", self->priv->dbus_id);
+}
+
+/*****************************************************************************/
+
 static void
 set_property (GObject *object,
               guint prop_id,
@@ -1349,6 +1437,8 @@ set_property (GObject *object,
         g_clear_object (&self->priv->modem);
         self->priv->modem = g_value_dup_object (value);
         if (self->priv->modem) {
+            /* Set owner ID */
+            mm_log_object_set_owner_id (MM_LOG_OBJECT (self), mm_log_object_get_id (MM_LOG_OBJECT (self->priv->modem)));
             /* Bind the modem's connection (which is set when it is exported,
              * and unset when unexported) to the BEARER's connection */
             g_object_bind_property (self->priv->modem, MM_BASE_MODEM_CONNECTION,
@@ -1427,14 +1517,21 @@ get_property (GObject *object,
 static void
 mm_base_bearer_init (MMBaseBearer *self)
 {
+    static guint id = 0;
+
     /* Initialize private data */
     self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
                                               MM_TYPE_BASE_BEARER,
                                               MMBaseBearerPrivate);
+
+    /* Each bearer is given a unique id to build its own DBus path */
+    self->priv->dbus_id = id++;
+
     self->priv->status = MM_BEARER_STATUS_DISCONNECTED;
     self->priv->reason_3gpp = CONNECTION_FORBIDDEN_REASON_NONE;
     self->priv->reason_cdma = CONNECTION_FORBIDDEN_REASON_NONE;
     self->priv->default_ip_family = MM_BEARER_IP_FAMILY_IPV4;
+    self->priv->stats = mm_bearer_stats_new ();
 
     /* Set defaults */
     mm_gdbus_bearer_set_interface   (MM_GDBUS_BEARER (self), NULL);
@@ -1447,6 +1544,7 @@ mm_base_bearer_init (MMBaseBearer *self)
                                      mm_bearer_ip_config_get_dictionary (NULL));
     mm_gdbus_bearer_set_ip6_config  (MM_GDBUS_BEARER (self),
                                      mm_bearer_ip_config_get_dictionary (NULL));
+    bearer_update_interface_stats (self);
 }
 
 static void
@@ -1482,6 +1580,12 @@ dispose (GObject *object)
     G_OBJECT_CLASS (mm_base_bearer_parent_class)->dispose (object);
 }
 
+static void
+log_object_iface_init (MMLogObjectInterface *iface)
+{
+    iface->build_id = log_object_build_id;
+}
+
 static void
 mm_base_bearer_class_init (MMBaseBearerClass *klass)
 {
