@@ -54,6 +54,20 @@ struct _MMCallListPrivate {
 
 /*****************************************************************************/
 
+void
+mm_call_list_foreach (MMCallList            *self,
+                      MMCallListForeachFunc  callback,
+                      gpointer               user_data)
+{
+    GList *l;
+
+    g_assert (callback);
+    for (l = self->priv->list; l; l = g_list_next (l))
+        callback (MM_BASE_CALL (l->data), user_data);
+}
+
+/*****************************************************************************/
+
 guint
 mm_call_list_get_count (MMCallList *self)
 {
@@ -84,10 +98,13 @@ mm_call_list_get_paths (MMCallList *self)
 /*****************************************************************************/
 
 MMBaseCall *
-mm_call_list_get_first_ringing_in_call (MMCallList *self)
+mm_call_list_get_first_incoming_call (MMCallList  *self,
+                                      MMCallState  incoming_state)
 {
     GList *l;
 
+    g_assert (incoming_state == MM_CALL_STATE_RINGING_IN || incoming_state == MM_CALL_STATE_WAITING);
+
     for (l = self->priv->list; l; l = g_list_next (l)) {
         MMBaseCall       *call;
         MMCallState       state;
@@ -101,7 +118,7 @@ mm_call_list_get_first_ringing_in_call (MMCallList *self)
                       NULL);
 
         if (direction == MM_CALL_DIRECTION_INCOMING &&
-            state     == MM_CALL_STATE_RINGING_IN) {
+            state     == incoming_state) {
             return call;
         }
     }
@@ -118,6 +135,19 @@ cmp_call_by_path (MMBaseCall *call,
     return g_strcmp0 (mm_base_call_get_path (call), path);
 }
 
+MMBaseCall *
+mm_call_list_get_call (MMCallList  *self,
+                       const gchar *call_path)
+{
+    GList *l;
+
+    l = g_list_find_custom (self->priv->list,
+                            (gpointer)call_path,
+                            (GCompareFunc)cmp_call_by_path);
+
+    return (l ? MM_BASE_CALL (l->data) : NULL);
+}
+
 gboolean
 mm_call_list_delete_call (MMCallList   *self,
                           const gchar  *call_path,
