@@ -80,9 +80,9 @@ typedef enum { /*< underscore_name=mm_filter_rule >*/
      MM_FILTER_RULE_TTY_WITH_NET          | \
      MM_FILTER_RULE_TTY_DEFAULT_FORBIDDEN)
 
-/* This is the default ModemManager policy that tries to automatically probe
+/* This is the legacy ModemManager policy that tries to automatically probe
  * device ports unless they're blacklisted in some way or another. */
-#define MM_FILTER_POLICY_DEFAULT           \
+#define MM_FILTER_POLICY_LEGACY            \
     (MM_FILTER_RULE_EXPLICIT_WHITELIST   | \
      MM_FILTER_RULE_EXPLICIT_BLACKLIST   | \
      MM_FILTER_RULE_VIRTUAL              | \
@@ -145,6 +145,8 @@ gboolean mm_filter_device_and_port (MMFilter       *self,
 
 void     mm_filter_register_plugin_whitelist_tag        (MMFilter    *self,
                                                          const gchar *tag);
+void     mm_filter_register_plugin_whitelist_vendor_id  (MMFilter    *self,
+                                                         guint16      vid);
 void     mm_filter_register_plugin_whitelist_product_id (MMFilter    *self,
                                                          guint16      vid,
                                                          guint16      pid);
