@@ -18,7 +18,50 @@
 #include <locale.h>
 
 #include "mm-modem-helpers.h"
-#include "mm-log.h"
+#include "mm-log-test.h"
+
+static void
+common_test_gsm7 (const gchar *in_utf8)
+{
+    guint32 unpacked_gsm_len = 0;
+    guint32 packed_gsm_len = 0;
+    guint32 unpacked_gsm_len_2 = 0;
+    g_autofree guint8 *unpacked_gsm = NULL;
+    g_autofree guint8 *packed_gsm = NULL;
+    g_autofree guint8 *unpacked_gsm_2 = NULL;
+    g_autofree gchar *built_utf8 = NULL;
+
+    /* Convert to GSM */
+    unpacked_gsm = mm_charset_utf8_to_unpacked_gsm (in_utf8, &unpacked_gsm_len);
+    g_assert_nonnull (unpacked_gsm);
+    g_assert_cmpuint (unpacked_gsm_len, >, 0);
+
+    /* Pack */
+    packed_gsm = mm_charset_gsm_pack (unpacked_gsm, unpacked_gsm_len, 0, &packed_gsm_len);
+    g_assert_nonnull (packed_gsm);
+    g_assert_cmpuint (packed_gsm_len, <=, unpacked_gsm_len);
+
+#if 0
+    {
+        g_autofree gchar *hex_packed = NULL;
+
+        /* Print */
+        hex_packed = mm_utils_bin2hexstr (packed_gsm, packed_gsm_len);
+        g_print ("----------\n");
+        g_print ("input string: '%s'\n", in_utf8);
+        g_print ("gsm-7 encoded string: %s\n", hex_packed);
+    }
+#endif
+
+    /* Unpack */
+    unpacked_gsm_2 = mm_charset_gsm_unpack (packed_gsm, packed_gsm_len * 8 / 7, 0, &unpacked_gsm_len_2);
+    g_assert_nonnull (unpacked_gsm_2);
+
+    /* And back to UTF-8 */
+    built_utf8 = (gchar *) mm_charset_gsm_unpacked_to_utf8 (unpacked_gsm_2, unpacked_gsm_len_2);
+    g_assert_nonnull (built_utf8);
+    g_assert_cmpstr (built_utf8, ==, in_utf8);
+}
 
 static void
 test_gsm7_default_chars (void)
@@ -27,21 +70,8 @@ test_gsm7_default_chars (void)
      * are converted from UTF-8 to GSM and back to UTF-8 successfully.
      */
     static const char *s = "@£$¥èéùìòÇ\nØø\rÅåΔ_ΦΓΛΩΠΨΣΘΞÆæßÉ !\"#¤%&'()*+,-./0123456789:;<=>?¡ABCDEFGHIJKLMNOPQRSTUVWXYZÄÖÑÜ§¿abcdefghijklmnopqrstuvwxyzäöñüà";
-    guint8 *gsm, *utf8;
-    guint32 len = 0;
 
-    /* Convert to GSM */
-    gsm = mm_charset_utf8_to_unpacked_gsm (s, &len);
-    g_assert (gsm);
-    g_assert_cmpint (len, ==, 127);
-
-    /* And back to UTF-8 */
-    utf8 = mm_charset_gsm_unpacked_to_utf8 (gsm, len);
-    g_assert (utf8);
-    g_assert_cmpstr (s, ==, (const char *) utf8);
-
-    g_free (gsm);
-    g_free (utf8);
+    common_test_gsm7 (s);
 }
 
 static void
@@ -51,21 +81,8 @@ test_gsm7_extended_chars (void)
      * charset are converted from UTF-8 to GSM and back to UTF-8 successfully.
      */
     static const char *s = "\f^{}\\[~]|€";
-    guint8 *gsm, *utf8;
-    guint32 len = 0;
 
-    /* Convert to GSM */
-    gsm = mm_charset_utf8_to_unpacked_gsm (s, &len);
-    g_assert (gsm);
-    g_assert_cmpint (len, ==, 20);
-
-    /* And back to UTF-8 */
-    utf8 = mm_charset_gsm_unpacked_to_utf8 (gsm, len);
-    g_assert (utf8);
-    g_assert_cmpstr (s, ==, (const char *) utf8);
-
-    g_free (gsm);
-    g_free (utf8);
+    common_test_gsm7 (s);
 }
 
 static void
@@ -75,21 +92,8 @@ test_gsm7_mixed_chars (void)
      * is converted from UTF-8 to GSM and back to UTF-8 successfully.
      */
     static const char *s = "@£$¥èéùìø\fΩΠΨΣΘ{ΞÆæß(})789\\:;<=>[?¡QRS]TUÖ|ÑÜ§¿abpqrstuvöñüà€";
-    guint8 *gsm, *utf8;
-    guint32 len = 0;
 
-    /* Convert to GSM */
-    gsm = mm_charset_utf8_to_unpacked_gsm (s, &len);
-    g_assert (gsm);
-    g_assert_cmpint (len, ==, 69);
-
-    /* And back to UTF-8 */
-    utf8 = mm_charset_gsm_unpacked_to_utf8 (gsm, len);
-    g_assert (utf8);
-    g_assert_cmpstr (s, ==, (const char *) utf8);
-
-    g_free (gsm);
-    g_free (utf8);
+    common_test_gsm7 (s);
 }
 
 static void
@@ -312,13 +316,15 @@ test_gsm7_pack_7_chars_offset (void)
 static void
 test_take_convert_ucs2_hex_utf8 (void)
 {
-    gchar *src, *converted;
+    gchar *src, *converted, *utf8;
 
     /* Ensure hex-encoded UCS-2 works */
     src = g_strdup ("0054002d004d006f00620069006c0065");
     converted = mm_charset_take_and_convert_to_utf8 (src, MM_MODEM_CHARSET_UCS2);
     g_assert_cmpstr (converted, ==, "T-Mobile");
-    g_free (converted);
+    utf8 = mm_utf8_take_and_convert_to_charset (converted, MM_MODEM_CHARSET_UCS2);
+    g_assert_cmpstr (utf8, ==, "0054002D004D006F00620069006C0065");
+    g_free (utf8);
 }
 
 static void
@@ -344,6 +350,19 @@ test_take_convert_ucs2_bad_ascii2 (void)
     g_assert (converted == NULL);
 }
 
+static void
+test_take_convert_gsm_utf8 (void)
+{
+    gchar *src, *converted, *utf8;
+
+    src = g_strdup ("T-Mobile");
+    converted = mm_charset_take_and_convert_to_utf8 (src, MM_MODEM_CHARSET_GSM);
+    g_assert_cmpstr (converted, ==, "T-Mobile");
+    utf8 = mm_utf8_take_and_convert_to_charset (converted, MM_MODEM_CHARSET_GSM);
+    g_assert_cmpstr (utf8, ==, "T-Mobile");
+    g_free (utf8);
+}
+
 struct charset_can_convert_to_test_s {
     const char *utf8;
     gboolean    to_gsm;
@@ -404,26 +423,6 @@ test_charset_can_covert_to (void)
     }
 }
 
-void
-_mm_log (const char *loc,
-         const char *func,
-         guint32 level,
-         const char *fmt,
-         ...)
-{
-    va_list args;
-    gchar *msg;
-
-    if (!g_test_verbose ())
-        return;
-
-    va_start (args, fmt);
-    msg = g_strdup_vprintf (fmt, args);
-    va_end (args);
-    g_print ("%s\n", msg);
-    g_free (msg);
-}
-
 int main (int argc, char **argv)
 {
     setlocale (LC_ALL, "");
@@ -446,6 +445,7 @@ int main (int argc, char **argv)
     g_test_add_func ("/MM/charsets/take-convert/ucs2/hex",         test_take_convert_ucs2_hex_utf8);
     g_test_add_func ("/MM/charsets/take-convert/ucs2/bad-ascii",   test_take_convert_ucs2_bad_ascii);
     g_test_add_func ("/MM/charsets/take-convert/ucs2/bad-ascii-2", test_take_convert_ucs2_bad_ascii2);
+    g_test_add_func ("/MM/charsets/take-convert/gsm",              test_take_convert_gsm_utf8);
 
     g_test_add_func ("/MM/charsets/can-convert-to", test_charset_can_covert_to);
 
